==> knative-model-6.8.1-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/LoadBalancerIngressStatusFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerIngressStatusFluent<A extends LoadBalancerIngressStatusFluent<A>> extends BaseFluent<A>{
  public LoadBalancerIngressStatusFluent() {
  }
  public LoadBalancerIngressStatusFluent(LoadBalancerIngressStatus instance) {
    instance = (instance != null ? instance : new LoadBalancerIngressStatus());

    if (instance != null) {
      this.withDomain(instance.getDomain());
      this.withDomainInternal(instance.getDomainInternal());
      this.withIp(instance.getIp());
      this.withMeshOnly(instance.getMeshOnly());
      this.withDomain(instance.getDomain());
      this.withDomainInternal(instance.getDomainInternal());
      this.withIp(instance.getIp());
      this.withMeshOnly(instance.getMeshOnly());
    }
  }
  private String domain;
  private String domainInternal;
  private String ip;
  private Boolean meshOnly;
  public String getDomain() {
    return this.domain;
  }
  public A withDomain(String domain) {
    this.domain=domain; return (A) this;
  }
  public boolean hasDomain() {
    return this.domain != null;
  }
  public String getDomainInternal() {
    return this.domainInternal;
  }
  public A withDomainInternal(String domainInternal) {
    this.domainInternal=domainInternal; return (A) this;
  }
  public boolean hasDomainInternal() {
    return this.domainInternal != null;
  }
  public String getIp() {
    return this.ip;
  }
  public A withIp(String ip) {
    this.ip=ip; return (A) this;
  }
  public boolean hasIp() {
    return this.ip != null;
  }
  public Boolean getMeshOnly() {
    return this.meshOnly;
  }
  public A withMeshOnly(Boolean meshOnly) {
    this.meshOnly=meshOnly; return (A) this;
  }
  public boolean hasMeshOnly() {
    return this.meshOnly != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerIngressStatusFluent that = (LoadBalancerIngressStatusFluent) o;
    if (!java.util.Objects.equals(domain, that.domain)) return false;

    if (!java.util.Objects.equals(domainInternal, that.domainInternal)) return false;

    if (!java.util.Objects.equals(ip, that.ip)) return false;

    if (!java.util.Objects.equals(meshOnly, that.meshOnly)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(domain,  domainInternal,  ip,  meshOnly,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domain != null) { sb.append("domain:"); sb.append(domain + ","); }
    if (domainInternal != null) { sb.append("domainInternal:"); sb.append(domainInternal + ","); }
    if (ip != null) { sb.append("ip:"); sb.append(ip + ","); }
    if (meshOnly != null) { sb.append("meshOnly:"); sb.append(meshOnly); }
    sb.append("}");
    return sb.toString();
  }
  public A withMeshOnly() {
    return withMeshOnly(true);
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/LoadBalancerIngressStatusFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerIngressStatusFluent<A extends LoadBalancerIngressStatusFluent<A>> extends BaseFluent<A>{
  public LoadBalancerIngressStatusFluent() {
  }
  
  public LoadBalancerIngressStatusFluent(LoadBalancerIngressStatus instance) {
    this.copyInstance(instance);
  }
  private String domain;
  private String domainInternal;
  private String ip;
  private Boolean meshOnly;
  
  protected void copyInstance(LoadBalancerIngressStatus instance) {
    instance = (instance != null ? instance : new LoadBalancerIngressStatus());
  
    if (instance != null) {
        this.withDomain(instance.getDomain());
        this.withDomainInternal(instance.getDomainInternal());
        this.withIp(instance.getIp());
        this.withMeshOnly(instance.getMeshOnly());
        this.withDomain(instance.getDomain());
        this.withDomainInternal(instance.getDomainInternal());
        this.withIp(instance.getIp());
        this.withMeshOnly(instance.getMeshOnly());
      }
  }
  
  public String getDomain() {
    return this.domain;
  }
  
  public A withDomain(String domain) {
    this.domain=domain; return (A) this;
  }
  
  public boolean hasDomain() {
    return this.domain != null;
  }
  
  public String getDomainInternal() {
    return this.domainInternal;
  }
  
  public A withDomainInternal(String domainInternal) {
    this.domainInternal=domainInternal; return (A) this;
  }
  
  public boolean hasDomainInternal() {
    return this.domainInternal != null;
  }
  
  public String getIp() {
    return this.ip;
  }
  
  public A withIp(String ip) {
    this.ip=ip; return (A) this;
  }
  
  public boolean hasIp() {
    return this.ip != null;
  }
  
  public Boolean getMeshOnly() {
    return this.meshOnly;
  }
  
  public A withMeshOnly(Boolean meshOnly) {
    this.meshOnly=meshOnly; return (A) this;
  }
  
  public boolean hasMeshOnly() {
    return this.meshOnly != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerIngressStatusFluent that = (LoadBalancerIngressStatusFluent) o;
    if (!java.util.Objects.equals(domain, that.domain)) return false;
  
    if (!java.util.Objects.equals(domainInternal, that.domainInternal)) return false;
  
    if (!java.util.Objects.equals(ip, that.ip)) return false;
  
    if (!java.util.Objects.equals(meshOnly, that.meshOnly)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(domain,  domainInternal,  ip,  meshOnly,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domain != null) { sb.append("domain:"); sb.append(domain + ","); }
    if (domainInternal != null) { sb.append("domainInternal:"); sb.append(domainInternal + ","); }
    if (ip != null) { sb.append("ip:"); sb.append(ip + ","); }
    if (meshOnly != null) { sb.append("meshOnly:"); sb.append(meshOnly); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withMeshOnly() {
    return withMeshOnly(true);
  }
  

}
